#include "Arduino.h"
#include <FastLED.h>
#include "TFT_eSPI.h" // use the TFT library modified for T-Display-S3
#include <WiFi.h>
#include "time.h"
#include "Audio.h"

#define NUM_LEDS    16
#define LED_PIN     2
#define I2S_BCLK    18
#define I2S_LRC     17
#define I2S_DOUT    16
#define RBUT_PIN    21
#define LBUT_PIN    13

const char* ssid     = "****";
const char* password = "****";

Audio audio;

TFT_eSPI lcd = TFT_eSPI();
TFT_eSprite sprite = TFT_eSprite(&lcd);

CRGB leds[NUM_LEDS];

const char* ntpServer = "pool.ntp.org";
const long  gmtOffset_sec = (-5) * 3600;  // Eastern Time (Miami) = -5 HRS
const int   daylightOffset_sec = 3600;  
struct tm   timeinfo;
char timeHour[3]="00";
char timeMin[3]="00";
int counter=0;
int playing=0;

void setup(void)
{
  delay(2000);
  FastLED.addLeds<WS2812B, LED_PIN, GRB>(leds, NUM_LEDS); 
  lcd.init();
  lcd.fillScreen(TFT_BLACK);
  lcd.setRotation(3);
    
   WiFi.begin(ssid, password);
   while (WiFi.status() != WL_CONNECTED) {
    delay(500);
    Serial.print(".");
  }
  configTime(gmtOffset_sec, daylightOffset_sec, ntpServer);

  pinMode(RBUT_PIN, INPUT_PULLUP);
  pinMode(LBUT_PIN, INPUT_PULLUP);

  sprite.createSprite(320, 170);
  sprite.setTextDatum(3);
  sprite.setSwapBytes(true);

  audio.setPinout(I2S_BCLK, I2S_LRC, I2S_DOUT);
  audio.setVolume(100);
  audio.connecttohost("http://somafm.com/defcon.pls");
}

void loop()
{
  if(playing){
    audio.loop();
    if(digitalRead(LBUT_PIN) == 0){
      playing=0;
      step_all_leds(CRGB::Red);
    }
  } else {
    if(digitalRead(RBUT_PIN) == 0) {
      playing=1;
      step_all_leds(CRGB::Green);
    }
  }

  counter++;
  if (counter==10000) {
    getLocalTime(&timeinfo);
    strftime(timeHour,3, "%H", &timeinfo);
    strftime(timeMin,3, "%M", &timeinfo);
    sprite.fillSprite(TFT_BLACK);
    sprite.setTextColor(TFT_WHITE,0x0967);
    sprite.fillRoundRect(26,10,130,105,10,0x0967);
    sprite.fillRoundRect(165,10,130,105,10,0x0967);
    sprite.drawString(String(timeHour),36,60,8);
    sprite.drawString(String(timeMin),175,60,8);
    sprite.pushSprite(0,0);
    counter=0;
  }
} 

void step_all_leds(CRGB indicator) {
   for(int curLed = 0; curLed < NUM_LEDS; curLed = curLed + 1) {
      leds[curLed] = indicator;
      FastLED.show();
      delay(80);
      leds[curLed] = CRGB::Black;
   }
   FastLED.show();
}
  
